@@ -178,7 +178,7 @@ def update_database_on_remote():
     run("rm -f /tmp/%(DB_USER)s.sql" % wp_config['remote'])
 
 
-def deploy(revision="master"):
+def deploy(revision="master", preprocessor=None):
     require('base_dir', provided_by=("env_test", "env_live"),
             used_for='defining the deploy environment')
 
@@ -187,6 +187,9 @@ def deploy(revision="master"):
     with lcd(env.local_base_dir):
         local('git archive %s %s | tar -x -f- -C %s' % (revision, env.local_wordpress_path, deploy_archive_dir))
 
+        if preprocessor:
+            preprocessor()
+
     local('rsync -a --exclude wp-config.php --exclude wp-content/uploads/* %s/%s/* %s@%s:%s/%s' %
           (deploy_archive_dir, env.local_wordpress_path, env.user, env.host,
            env.base_dir, env.wordpress_path))
